Donno is a note utility aimed at replacing Evernote for console fans.

# Features

* Work in Linux console;

* Taged notes;

* Powerful search functionality;

* Sync with Cloud;

* Import from Evernote;

* Auto-publis to blog;

# Introduction

Evernote is a wonderful application. However, it's GUI-based, which is not a 
problem on Windows, but makes Linux console fans pain. As a proprietary 
software, it's not open enough to add new features, for example, add a console
wrapper on it. So after half-a-year running Evernote Windows in wine on my
Linux laptop, I wrote this "Donno" which has similiar features of Evernote, but
is completely console thing. Now I imported all my notes to this app, and have 
a happy life ...

## Search Function

* Simple and complex modes;

* Case-insensitive;

## Note Syntax

* Markdown

# Installation

1. Copy all note files to ~/.repo if you already have any notes;

1. pip install donno;
